======
ROSE 2
======

Rank ordering of super-enhancers.

Install
=======

```
pip install -e git+https://github.com/linlabbcm/rose2.git#egg=rose2
```

Dependencies
============

ROSE 2 requires [Bamliquidator](https://github.com/BradnerLab/pipeline/wiki/bamliquidator).
